==> paraselene-2.0.0.src.tar.gz: paraselene-2.0.0/output_sample/source/logic/logic.java <==
// Paraselene generated this source file.
package #1.logic#2;

import #1.*;
import #1.base.*;
import paraselene.*;
import paraselene.supervisor.*;
import paraselene.tag.*;
import paraselene.tag.form.*;
import paraselene.tag.list.*;
import paraselene.tag.table.*;
import paraselene.css.*;

/**
 * #3
 */
public class #4 extends #1.view#2.#4 {
	private static final long serialVersionUID = 1L;

	/**
	 * コンストラクタ。
	 */
	public #4() {
		super();
		init();
	}

	/**
	 * 初期化。
	 */
	public void init(){
		super.init();
		// モックアップHTMLの内容と異なる内容で初期化したい場合は
		// super.init()の後に変更用の処理を記述して下さい。
		// このメソッドは上記コンストラクタの中から呼ばれます。
		// インスタンス発生はバックグラウンドで非同期に処理していますので
		// HTTPリクエスト発生よりずっと過去に初期化されます。
		// このため、ユーザーのトランザクションに応じた条件分岐を設けても
		// 意図した振る舞いになりません。
	}

	/**
	 * 別名URI設定。nullを返すと別名は設定しません。
	 * 最低４文字指定して下さい。
	 * ".na"で終えると完全一致となりますが、".na"で無ければ先頭一致となります。
	 * @return URI。
	 */
	public String getAliasURI() {
		return null;
	}

	/**
	 * 入力値の検証を行う。
	 * このメソッドが呼ばれる際には必ずセッションが発生しています。
	 * 入力値のエラーチェックや入力値に即した動作を記述します。
	 * @param req リクエスト内容。
	 * @param fw デフォルト遷移先。
	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
	 */
	public Forward inputMain( RequestParameter req, Forward fw ) throws PageException {
		// fwにはモックアップと同じ遷移先が設定されています。
		// 別の遷移先としたい場合は、新しくForwardインスタンスを生成して
		// リターンして下さい。
		return fw;
	}

	/**
	 * 出力情報の設定を行う。
	 * @param from 遷移元ページ。直接呼ばれている場合はnullです。
	 * @param req リクエスト内容。
	 * @return 出力ページ。
	 * nullを返すとthisをリターンしたのと同じ扱いにされます。
	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
	 */
	public Page outputMain( Page from, RequestParameter req ) throws PageException {
		// 出力内容を設定します。
		// 初期化したい場合は、init()をコールして下さい。
		return this;
	}
}

==> paraselene-2.0.3.src.tar.gz: paraselene-2.0.3/output_sample/source/logic/logic.java <==
// Paraselene generated this source file.
package #1.logic#2;

import #1.*;
import #1.base.*;
import paraselene.*;
import paraselene.supervisor.*;
import paraselene.tag.*;
import paraselene.tag.form.*;
import paraselene.tag.list.*;
import paraselene.tag.table.*;
import paraselene.css.*;

/**
 * #3
 */
public class #4 extends #1.view#2.#4 {
	private static final long serialVersionUID = 1L;

	/**
	 * コンストラクタ。
	 */
	public #4() {
		super();
		init();
	}

	/**
	 * 初期化。
	 */
	public void init(){
		super.init();
		// モックアップHTMLの内容と異なる内容で初期化したい場合は
		// super.init()の後に変更用の処理を記述して下さい。
		// このメソッドは上記コンストラクタの中から呼ばれます。
		// インスタンス発生はバックグラウンドで非同期に処理していますので
		// HTTPリクエスト発生よりずっと過去に初期化されます。
		// このため、ユーザーのトランザクションに応じた条件分岐を設けても
		// 意図した振る舞いになりません。
	}

	/**
	 * 別名URI設定。nullを返すと別名は設定しません。
	 * 最低４文字指定して下さい。
	 * ".na"で終えると完全一致となりますが、".na"で無ければ先頭一致となります。
	 * @return URI。
	 */
	public String getAliasURI() {
		return null;
	}

	/**
	 * 入力値の検証を行う。
	 * このメソッドが呼ばれる際には必ずセッションが発生しています。
	 * 入力値のエラーチェックや入力値に即した動作を記述します。
	 * @param req リクエスト内容。
	 * @param fw デフォルト遷移先。
	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
	 */
	public Forward inputMain( RequestParameter req, Forward fw ) throws PageException {
		// fwにはモックアップと同じ遷移先が設定されています。
		// 別の遷移先としたい場合は、新しくForwardインスタンスを生成して
		// リターンして下さい。
		return fw;
	}

	/**
	 * 初回outputの呼び出しメイン処理。
	 * @param req リクエスト内容。
	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
	 */
	public void firstOutputMain( RequestParameter req ) throws PageException {
		// 初期化処理があれば記述して下さい。
	}

	/**
	 * 出力情報の設定を行う。
	 * @param from 遷移元ページ。直接呼ばれている場合はnullです。
	 * @param req リクエスト内容。
	 * @return 出力ページ。
	 * nullを返すとthisをリターンしたのと同じ扱いにされます。
	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
	 */
	public Page outputMain( Page from, RequestParameter req ) throws PageException {
		// 出力内容を設定します。
		// 初期化したい場合は、init()をコールして下さい。
		return this;
	}
}
